@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 HELPER_SETTINGS = {
     'INSTALLED_APPS': [],
+    'SECRET_KEY': 'some-secret',
+    'ALLOWED_HOSTS': ['localhost'],
     'CMS_LANGUAGES': {
         1: [{
             'code': 'en',
@@ -8,13 +10,15 @@ HELPER_SETTINGS = {
         }]
     },
     'LANGUAGE_CODE': 'en',
-    'ALLOWED_HOSTS': ['localhost'],
 }
 
 
 def run():
     from app_helper import runner
-    runner.cms('aldryn_sso')
+    try:
+        runner.cms('aldryn_sso')
+    except ImportError:
+        runner.run('aldryn_sso')
 
 
 if __name__ == '__main__':
